@@ -115,7 +115,7 @@ if __name__ == "__main__":
         metavar="FASTA-file",
         nargs="+",
         action="append",
-        help=("the FASTA file(s) of sequences that were given to BLAST " "or DIAMOND."),
+        help=("the FASTA file(s) of sequences that were given to BLAST or DIAMOND."),
     )
 
     group.add_argument(
@@ -123,7 +123,7 @@ if __name__ == "__main__":
         metavar="FASTQ-file",
         nargs="+",
         action="append",
-        help=("the FASTQ file(s) of sequences that were given to BLAST " "or DIAMOND."),
+        help=("the FASTQ file(s) of sequences that were given to BLAST or DIAMOND."),
     )
 
     parser.add_argument(
@@ -165,7 +165,7 @@ if __name__ == "__main__":
     parser.add_argument(
         "--minStart",
         type=int,
-        help="Reads that start before this subject offset should not be " "shown.",
+        help="Reads that start before this subject offset should not be shown.",
     )
 
     parser.add_argument(
@@ -193,7 +193,7 @@ if __name__ == "__main__":
     parser.add_argument(
         "--scoreCutoff",
         type=float,
-        help=("A float score. Matches with scores worse than this will be " "ignored."),
+        help=("A float score. Matches with scores worse than this will be ignored."),
     )
 
     parser.add_argument(
@@ -232,7 +232,7 @@ if __name__ == "__main__":
 
     parser.add_argument(
         "--whitelistFile",
-        help=("A file containing sequence titles (one per line) to be " "whitelisted"),
+        help=("A file containing sequence titles (one per line) to be whitelisted"),
     )
 
     parser.add_argument(
@@ -244,7 +244,7 @@ if __name__ == "__main__":
 
     parser.add_argument(
         "--blacklistFile",
-        help=("A file containing sequence titles (one per line) to be " "blacklisted"),
+        help=("A file containing sequence titles (one per line) to be blacklisted"),
     )
 
     parser.add_argument("--titleRegex", help="a regex that sequence titles must match.")
@@ -352,8 +352,7 @@ if __name__ == "__main__":
         type=bool,
         default=False,
         help=(
-            "If True, display reads with a Y axis coord that is the rank of "
-            "the score."
+            "If True, display reads with a Y axis coord that is the rank of the score."
         ),
     )
 
