@@ -203,9 +203,9 @@ def basesToConsensus(
                     deletionSymbol if otherBases[offset] is None else otherBases[offset]
                 )
             else:
-                assert (
-                    offset in offsetBases
-                ), f"Offset {offset} not found in offsetBases or otherBases."
+                assert offset in offsetBases, (
+                    f"Offset {offset} not found in offsetBases or otherBases."
+                )
                 bases = offsetBases[offset]
                 result.append(
                     bases.consensus(
@@ -330,12 +330,12 @@ def consensusFromBAM(
     if referenceFasta is None:
         if lowCoverage == "reference":
             raise UnspecifiedReference(
-                'lowCoverage is "reference" but no ' "reference FASTA file was given."
+                'lowCoverage is "reference" but no reference FASTA file was given.'
             )
 
         if noCoverage == "reference":
             raise UnspecifiedReference(
-                'noCoverage is "reference" but no ' "reference FASTA file was given."
+                'noCoverage is "reference" but no reference FASTA file was given.'
             )
 
     with samfile(bamFilename) as bam:
@@ -510,7 +510,7 @@ def addPairsInfo(
     # soft clip (not an insertion).
     if pairs[0][1] is None:
         assert cigarOperations[0] == CSOFT_CLIP, (
-            f"First CIGAR operation is {cigarOperations[0]}, " f"not a soft clip"
+            f"First CIGAR operation is {cigarOperations[0]}, not a soft clip"
         )
 
     inInsertion = False
@@ -644,7 +644,7 @@ def fetchConsensus(
         debug("final insertions:")
         for offset in sorted(insertions):
             wanted = insertions[offset].readCount() >= insertionCountThreshold
-            debug(f'  {"" if wanted else "un"}wanted {insertions[offset]}')
+            debug(f"  {'' if wanted else 'un'}wanted {insertions[offset]}")
 
     with maybeProgressBar(progress, maxOffset - minOffset + 1, "Collect  : ") as bar:
         insertCount = 0
@@ -788,7 +788,7 @@ def compareCorrespondences(fp, fetch, pileup, threshold, minCoverage):
     common = fetchOffsets & pileupOffsets
     if common:
         print(
-            f"There are {len(common)} sites obtained from both fetch and " f"pileup.",
+            f"There are {len(common)} sites obtained from both fetch and pileup.",
             file=fp,
         )
         differenceCount = 0
